# This package is different from most node packages in Fedora because
# CoffeeScript is written in itself, and per Fedora policy we need to compile
# it--we can't ship the precompiled version.

%global commit f26d33d418dcdcfcc6ad3ab774d9cabbf7af659c
%global shortcommit %(c=%{commit}; echo ${c:0:7})

Name:           coffee-script
Version:        1.10.0
Release:        %mkrel 6
Summary:        A programming language that transcompiles to JavaScript
License:        MIT
Group:          Development/Other
URL:            http://coffeescript.org/
Source0:        https://github.com/jashkenas/%{name}/archive/%{commit}/%{name}-%{version}-%{shortcommit}.tar.gz
BuildArch:      noarch
ExclusiveArch: %{ix86} x86_64 %{arm} noarch
# some fixes for Cakefile, including:
#  - follow FHS and Fedora Node.js packaging guidelines
#  - support DESTDIR
#  - preserve timestamps when installing
Patch1:         %{name}-Cakefile.patch

Requires:       js-%{name} == %{version}-%{release}

BuildRequires:  nodejs-packaging
BuildRequires:  web-assets-devel
BuildRequires:  npm(underscore)
BuildRequires:  npm(uglify-js)

%description
CoffeeScript is a little language that compiles into JavaScript. Underneath all
of those embarrassing braces and semicolons, JavaScript has always had a
gorgeous object model at its heart. CoffeeScript is an attempt to expose the
good parts of JavaScript in a simple way.

The golden rule of CoffeeScript is: "It's just JavaScript". The code compiles
one-to-one into the equivalent JS, and there is no interpretation at runtime.
You can use any existing JavaScript library seamlessly (and vice-versa). The
compiled output is readable and pretty-printed, passes through JavaScript Lint
without warnings, will work in every JavaScript implementation, and tends to run
as fast or faster than the equivalent handwritten JavaScript.


%package -n js-%{name}
Summary:        A programming that transcompiles to JavaScript - core compiler
Group:          Development/Other

Provides:       %{name}-common = %{version}-%{release}
Obsoletes:      %{name}-common < 1.10.0-4

Requires:       web-assets-filesystem

%description -n js-%{name}
This is the core compiler for the CoffeeScript language, suitable for use in
browsers or by other JavaScript implementations.

For the primary compiler and cake utility used in conjunction with Node.js,
install the 'coffee-script' package.


%package doc
Summary:        A programming language that transcompiles to JavaScript - documentation
Group:          Documentation

%description doc
The documentation for the CoffeeScript programming language.


%prep
%setup -qn coffeescript-%{commit}
%patch1 -p1

#rename documentation directory to html cause that's what we want in %%doc
mv documentation html


%build
%nodejs_symlink_deps --build
./bin/cake build

#build the minified coffee-script browser version and put it in its place
./bin/cake build:browser
mv extras/coffee-script.js extras/coffee-script.min.js

#also build the unminifed version
MINIFY=false ./bin/cake build:browser


%install
mkdir -p %{buildroot}%{_jsdir}/%{name}/
cp -pr extras/* %{buildroot}%{_jsdir}/%{name}/

mkdir -p %{buildroot}%{_datadir}/%{name}/extras/
ln -s %{_jsdir}/%{name}/coffee-script.js %{buildroot}%{_datadir}/%{name}/extras/
ln -s %{_jsdir}/%{name}/coffee-script.min.js %{buildroot}%{_datadir}/%{name}/extras/

mkdir -p %{buildroot}%{nodejs_sitelib}/%{name}
cp -pr *.js bin lib package.json %{buildroot}%{nodejs_sitelib}/%{name}
chmod 0644 %{buildroot}%{nodejs_sitelib}/%{name}/lib/coffee-script/parser.js
ln -sf %{_datadir}/%{name}/extras %{buildroot}%{nodejs_sitelib}/%{name}/extras

mkdir -p %{buildroot}%{_bindir}
ln -sf ../lib/node_modules/%{name}/bin/coffee %{buildroot}%{_bindir}/coffee
ln -sf ../lib/node_modules/%{name}/bin/cake %{buildroot}%{_bindir}/cake

#we skip %%nodejs_symlink_deps because this package has no dependencies, and if
#it did, would need special treatment anyway


%check
./bin/cake test


%pretrans -p <lua>
path = "%{nodejs_sitelib}/%{name}/lib"
st = posix.stat(path)
if st and st.type == "link" then
  os.remove(path)
end


%files
%{nodejs_sitelib}/%{name}
%{_bindir}/coffee
%{_bindir}/cake


%files -n js-%{name}
%doc README.md
%license LICENSE
%{_jsdir}/%{name}
%{_datadir}/%{name}


%files doc
%doc html



%changelog
* Fri May 20 2016 neoclust <neoclust> 1.10.0-6.mga6
+ Revision: 1017132
- enable minified

* Fri May 13 2016 joequant <joequant> 1.10.0-1.mga6
+ Revision: 1014457
- add symlinks
- add dep
- upgrade to 1.10.0

* Thu Feb 04 2016 umeabot <umeabot> 1.6.3-6.mga6
+ Revision: 935990
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.6.3-5.mga5
+ Revision: 739843
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.6.3-4.mga5
+ Revision: 725006
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.6.3-3.mga5
+ Revision: 678468
- Mageia 5 Mass Rebuild

* Wed Jul 23 2014 joequant <joequant> 1.6.3-2.mga5
+ Revision: 655897
- minor spec fixes
- imported package coffee-script

